[2184] 2009-05-04 Pavel Roskin <[email protected]>

Pavel Roskin <[email protected]>
Newsgroups gmane.comp.boot-loaders.grub.cvs
Message-ID <[email protected]>
Revision: 2184
          http://svn.sv.gnu.org/viewvc/?view=rev&root=grub&revision=2184
Author:   proski
Date:     2009-05-04 20:06:05 +0000 (Mon, 04 May 2009)
Log Message:
-----------
2009-05-04  Pavel Roskin  <[email protected]>

	* disk/ata.c: Spelling fixes.
	* disk/raid.c: Likewise.
	* disk/usbms.c: Likewise.
	* disk/dmraid_nvidia.c: Likewise.
	* kern/ieee1275/openfw.c: Likewise.
	* kern/ieee1275/init.c: Likewise.
	* kern/ieee1275/cmain.c: Likewise.
	* boot/i386/pc/cdboot.S: Likewise.
	* video/readers/png.c: Likewise.
	* video/i386/pc/vbe.c: Likewise.
	* fs/udf.c: Likewise.
	* fs/hfs.c: Likewise.
	* fs/reiserfs.c: Likewise.
	* efiemu/runtime/efiemu.c: Likewise.
	* efiemu/main.c: Likewise.
	* efiemu/mm.c: Likewise.
	* include/grub/elf.h: Likewise.
	* include/grub/xnu.h: Likewise.
	* include/grub/usbdesc.h: Likewise.
	* include/grub/usb.h: Likewise.
	* include/grub/script_sh.h: Likewise.
	* include/grub/lib/LzmaEnc.h: Likewise.
	* include/grub/efiemu/efiemu.h: Likewise.
	* include/grub/command.h: Likewise.
	* normal/menu.c: Likewise.
	* normal/main.c: Likewise.
	* normal/datetime.c: Likewise.
	* bus/usb/uhci.c: Likewise.
	* mmap/i386/uppermem.c: Likewise.
	* mmap/mmap.c: Likewise.
	* commands/acpi.c: Likewise.
	* commands/test.c: Likewise.
	* partmap/apple.c: Likewise.
	* font/font.c: Likewise.
	* loader/sparc64/ieee1275/linux.c: Likewise.
	* loader/macho.c: Likewise.
	* loader/i386/bsd_trampoline.S: Likewise.
	* loader/i386/bsd.c: Likewise.
	* loader/xnu.c: Likewise.
	* term/i386/pc/vesafb.c: Likewise.
	* term/usb_keyboard.c: Likewise.
	* util/resolve.c: Likewise.
	* util/getroot.c: Likewise.

Modified Paths:
--------------
    trunk/grub2/ChangeLog
    trunk/grub2/boot/i386/pc/cdboot.S
    trunk/grub2/bus/usb/uhci.c
    trunk/grub2/commands/acpi.c
    trunk/grub2/commands/test.c
    trunk/grub2/disk/ata.c
    trunk/grub2/disk/dmraid_nvidia.c
    trunk/grub2/disk/raid.c
    trunk/grub2/disk/usbms.c
    trunk/grub2/efiemu/main.c
    trunk/grub2/efiemu/mm.c
    trunk/grub2/efiemu/runtime/efiemu.c
    trunk/grub2/font/font.c
    trunk/grub2/fs/hfs.c
    trunk/grub2/fs/reiserfs.c
    trunk/grub2/fs/udf.c
    trunk/grub2/include/grub/command.h
    trunk/grub2/include/grub/efiemu/efiemu.h
    trunk/grub2/include/grub/elf.h
    trunk/grub2/include/grub/lib/LzmaEnc.h
    trunk/grub2/include/grub/script_sh.h
    trunk/grub2/include/grub/usb.h
    trunk/grub2/include/grub/usbdesc.h
    trunk/grub2/include/grub/xnu.h
    trunk/grub2/kern/ieee1275/cmain.c
    trunk/grub2/kern/ieee1275/init.c
    trunk/grub2/kern/ieee1275/openfw.c
    trunk/grub2/loader/i386/bsd.c
    trunk/grub2/loader/i386/bsd_trampoline.S
    trunk/grub2/loader/macho.c
    trunk/grub2/loader/sparc64/ieee1275/linux.c
    trunk/grub2/loader/xnu.c
    trunk/grub2/mmap/i386/uppermem.c
    trunk/grub2/mmap/mmap.c
    trunk/grub2/normal/datetime.c
    trunk/grub2/normal/main.c
    trunk/grub2/normal/menu.c
    trunk/grub2/partmap/apple.c
    trunk/grub2/term/i386/pc/vesafb.c
    trunk/grub2/term/usb_keyboard.c
    trunk/grub2/util/getroot.c
    trunk/grub2/util/resolve.c
    trunk/grub2/video/i386/pc/vbe.c
    trunk/grub2/video/readers/png.c

Modified: trunk/grub2/ChangeLog
===================================================================
--- trunk/grub2/ChangeLog	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/ChangeLog	2009-05-04 20:06:05 UTC (rev 2184)
@@ -1,3 +1,49 @@
+2009-05-04  Pavel Roskin  <[email protected]>
+
+	* disk/ata.c: Spelling fixes.
+	* disk/raid.c: Likewise.
+	* disk/usbms.c: Likewise.
+	* disk/dmraid_nvidia.c: Likewise.
+	* kern/ieee1275/openfw.c: Likewise.
+	* kern/ieee1275/init.c: Likewise.
+	* kern/ieee1275/cmain.c: Likewise.
+	* boot/i386/pc/cdboot.S: Likewise.
+	* video/readers/png.c: Likewise.
+	* video/i386/pc/vbe.c: Likewise.
+	* fs/udf.c: Likewise.
+	* fs/hfs.c: Likewise.
+	* fs/reiserfs.c: Likewise.
+	* efiemu/runtime/efiemu.c: Likewise.
+	* efiemu/main.c: Likewise.
+	* efiemu/mm.c: Likewise.
+	* include/grub/elf.h: Likewise.
+	* include/grub/xnu.h: Likewise.
+	* include/grub/usbdesc.h: Likewise.
+	* include/grub/usb.h: Likewise.
+	* include/grub/script_sh.h: Likewise.
+	* include/grub/lib/LzmaEnc.h: Likewise.
+	* include/grub/efiemu/efiemu.h: Likewise.
+	* include/grub/command.h: Likewise.
+	* normal/menu.c: Likewise.
+	* normal/main.c: Likewise.
+	* normal/datetime.c: Likewise.
+	* bus/usb/uhci.c: Likewise.
+	* mmap/i386/uppermem.c: Likewise.
+	* mmap/mmap.c: Likewise.
+	* commands/acpi.c: Likewise.
+	* commands/test.c: Likewise.
+	* partmap/apple.c: Likewise.
+	* font/font.c: Likewise.
+	* loader/sparc64/ieee1275/linux.c: Likewise.
+	* loader/macho.c: Likewise.
+	* loader/i386/bsd_trampoline.S: Likewise.
+	* loader/i386/bsd.c: Likewise.
+	* loader/xnu.c: Likewise.
+	* term/i386/pc/vesafb.c: Likewise.
+	* term/usb_keyboard.c: Likewise.
+	* util/resolve.c: Likewise.
+	* util/getroot.c: Likewise.
+
 2009-05-04  Felix Zielcke  <[email protected]>
 
 	* conf/i386-pc.rmk (libpkg_DATA): Rename to pkglib_DATA.

Modified: trunk/grub2/boot/i386/pc/cdboot.S
===================================================================
--- trunk/grub2/boot/i386/pc/cdboot.S	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/boot/i386/pc/cdboot.S	2009-05-04 20:06:05 UTC (rev 2184)
@@ -46,7 +46,7 @@
 	. = start + 8
 
 bi_pvd:
-	.long 0		/* LBA of primary volume descript.  */
+	.long 0		/* LBA of primary volume descriptor.  */
 bi_file:
 	.long 0		/* LBA of boot file. */
 bi_length:

Modified: trunk/grub2/bus/usb/uhci.c
===================================================================
--- trunk/grub2/commands/acpi.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/commands/acpi.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -53,7 +53,7 @@
   {"oemtablecreatorrev", 'd', 0, 
    "Set creator revision of RSDP, XSDT and RSDT", 0, ARG_TYPE_INT},  
   {"no-ebda", 'e', 0, "Don't update EBDA. May fix failures or hangs on some"
-   " BIOSes but makes it uneffective with OS not recieving RSDP fro GRUB", 
+   " BIOSes but makes it ineffective with OS not receiving RSDP from GRUB",
    0, ARG_TYPE_NONE},
   {0, 0, 0, 0, 0, 0}
 };
@@ -186,7 +186,7 @@
   if (! mmapregion)
     return grub_errno;
 
-  /* XXX: EBDA is unstandartised, so this implementation is heuristical. */
+  /* XXX: EBDA is unstandardized, so this implementation is heuristical. */
   if (ebda_kb_len)
     grub_memcpy (targetebda, ebda, 0x400);
   else
@@ -503,7 +503,7 @@
 	    *ptr = grub_tolower (*ptr);
 	}
 
-      /* Set revision variables to replicant the same version as host. */
+      /* Set revision variables to replicate the same version as host. */
       rev1 = ! rsdp->revision;
       rev2 = rsdp->revision;
       rsdt = (struct grub_acpi_table_header *) UINT_TO_PTR (rsdp->rsdt_addr);
@@ -558,7 +558,7 @@
 		  grub_memcpy (table_dsdt, dsdt, dsdt->length);
 		}
 
-	      /* Save FACS address. FACS shouldn't be overriden. */
+	      /* Save FACS address. FACS shouldn't be overridden. */
 	      facs_addr = fadt->facs_addr;
 	    }
   

Modified: trunk/grub2/commands/test.c
===================================================================
--- trunk/grub2/commands/test.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/commands/test.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -35,7 +35,7 @@
   return grub_strtoul (arg, end, base);
 }
 
-/* Parse a test expression startion from *argn. */
+/* Parse a test expression starting from *argn. */
 static int
 test_parse (char **args, int *argn, int argc)
 {

Modified: trunk/grub2/disk/ata.c
===================================================================
--- trunk/grub2/disk/ata.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/disk/ata.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -439,7 +439,7 @@
 	  grub_errno = GRUB_ERR_NONE;
 	  grub_ata_device_initialize (controller * 2 + i, 0, rega, regb);
 
-	  /* Most errors rised by grub_ata_device_initialize() are harmless.
+	  /* Most errors raised by grub_ata_device_initialize() are harmless.
 	     They just indicate this particular drive is not responding, most
 	     likely because it doesn't exist.  We might want to ignore specific
 	     error types here, instead of printing them.  */
@@ -586,7 +586,7 @@
 
       grub_dprintf("ata", "rw=%d, sector=%llu, batch=%u\n", rw, sector, batch);
 
-      /* Send read/write commmand.  */
+      /* Send read/write command.  */
       if (grub_ata_setaddress (dev, addressing, sector, batch))
 	return grub_errno;
 

Modified: trunk/grub2/disk/dmraid_nvidia.c
===================================================================
--- trunk/grub2/disk/dmraid_nvidia.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/disk/dmraid_nvidia.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -42,7 +42,7 @@
 #define NV_LEVEL_1_0		0x8180
 
 #define NV_ARRAY_FLAG_BOOT		1 /* BIOS use only.  */
-#define NV_ARRAY_FLAG_ERROR		2 /* Degraded or offling.  */
+#define NV_ARRAY_FLAG_ERROR		2 /* Degraded or offline.  */
 #define NV_ARRAY_FLAG_PARITY_VALID	4 /* RAID-3/5 parity valid.  */
 
 struct grub_nv_array

Modified: trunk/grub2/disk/raid.c
===================================================================
--- trunk/grub2/disk/raid.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/disk/raid.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -573,7 +573,7 @@
       array->next = array_list;
       array_list = array;
 
-      /* RAID 1 doestn't use a chunksize but code assumes one so set
+      /* RAID 1 doesn't use a chunksize but code assumes one so set
 	 one. */
       if (array->level == 1)
 	array->chunk_size = 64;

Modified: trunk/grub2/disk/usbms.c
===================================================================
--- trunk/grub2/disk/usbms.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/disk/usbms.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -179,7 +179,7 @@
 	  /* XXX: Activate the first configuration.  */
 	  grub_usb_set_configuration (usbdev, 1);
 
-	  /* Bolk-Only Mass Storage Reset, after the reset commands
+	  /* Bulk-Only Mass Storage Reset, after the reset commands
 	     will be accepted.  */
 	  grub_usbms_reset (usbdev, i);
 
@@ -214,8 +214,8 @@
 }
 
 static grub_err_t
-grub_usbms_tranfer (struct grub_scsi *scsi, grub_size_t cmdsize, char *cmd,
-		    grub_size_t size, char *buf, int read_write)
+grub_usbms_transfer (struct grub_scsi *scsi, grub_size_t cmdsize, char *cmd,
+		     grub_size_t size, char *buf, int read_write)
 {
   struct grub_usbms_cbw cbw;
   grub_usbms_dev_t dev = (grub_usbms_dev_t) scsi->data;
@@ -322,14 +322,14 @@
 grub_usbms_read (struct grub_scsi *scsi, grub_size_t cmdsize, char *cmd,
 		 grub_size_t size, char *buf)
 {
-  return grub_usbms_tranfer (scsi, cmdsize, cmd, size, buf, 0);
+  return grub_usbms_transfer (scsi, cmdsize, cmd, size, buf, 0);
 }
 
 static grub_err_t
 grub_usbms_write (struct grub_scsi *scsi, grub_size_t cmdsize, char *cmd,
 		  grub_size_t size, char *buf)
 {
-  return grub_usbms_tranfer (scsi, cmdsize, cmd, size, buf, 1);
+  return grub_usbms_transfer (scsi, cmdsize, cmd, size, buf, 1);
 }
 
 static grub_err_t

Modified: trunk/grub2/efiemu/main.c
===================================================================
--- trunk/grub2/efiemu/main.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/efiemu/main.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -214,7 +214,7 @@
       return grub_error (grub_errno, "Couldn't init memory management");
     }
 
-  grub_dprintf ("efiemu", "mm inited\n");
+  grub_dprintf ("efiemu", "mm initialized\n");
 
   err = grub_efiemu_loadcore_init (file);
   if (err)

Modified: trunk/grub2/efiemu/mm.c
===================================================================
--- trunk/grub2/efiemu/mm.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/efiemu/mm.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -18,7 +18,7 @@
  */
 /*
   To keep efiemu runtime contiguous this mm is special. 
-  It uses deffered allocation.
+  It uses deferred allocation.
   In the first stage you may request memory with grub_efiemu_request_memalign
   It will give you a handle with which in the second phase you can access your 
   memory with grub_efiemu_mm_obtain_request (handle). It's guaranteed that
@@ -624,7 +624,7 @@
   if (!efiemu_mmap)
     {
       grub_efiemu_unload ();
-      return grub_error (GRUB_ERR_OUT_OF_MEMORY, "Couldn't initilaize mmap");
+      return grub_error (GRUB_ERR_OUT_OF_MEMORY, "Couldn't initialize mmap");
     }
 
   if ((err = efiemu_alloc_requests ()))

Modified: trunk/grub2/efiemu/runtime/efiemu.c
===================================================================
--- trunk/grub2/efiemu/runtime/efiemu.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/efiemu/runtime/efiemu.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -116,7 +116,7 @@
 extern grub_uint8_t efiemu_time_daylight;
 extern grub_uint32_t efiemu_time_accuracy;
 
-/* Some standard functions because we need to be stadalone */
+/* Some standard functions because we need to be standalone */
 static void
 efiemu_memcpy (void *to, void *from, int count)
 {
@@ -251,7 +251,7 @@
   return GRUB_EFI_SUCCESS;
 }
 
-/* Folowing 2 functions are vendor specific. So announce it as unsupported */
+/* Following 2 functions are vendor specific. So announce it as unsupported */
 grub_efi_status_t
 EFI_FUNC (efiemu_get_wakeup_time) (grub_efi_boolean_t *enabled,
 				      grub_efi_boolean_t *pending,

Modified: trunk/grub2/font/font.c
===================================================================
--- trunk/grub2/font/font.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/font/font.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -186,7 +186,7 @@
 
    On success, the section name is stored in section->name and the length in
    section->length, and 0 is returned.  On failure, 1 is returned and
-   grub_errno is set approriately with an error message.
+   grub_errno is set appropriately with an error message.
 
    If 1 is returned due to being at the end of the file, then section->eof is
    set to 1; otherwise, section->eof is set to 0.  */

Modified: trunk/grub2/fs/hfs.c
===================================================================
--- trunk/grub2/fs/hfs.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/fs/hfs.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -124,7 +124,7 @@
   grub_uint16_t first_block;
 } __attribute__ ((packed));
 
-/* A dirrect record.  This is used to find out the directory ID.  */
+/* A directory record.  This is used to find out the directory ID.  */
 struct grub_hfs_dirrec
 {
   /* For a directory, type == 1.  */
@@ -744,7 +744,7 @@
       else
 	cmp = grub_hfs_cmp_extkeys (rec->key, (void *) key);
       
-      /* If the key is smaller or equal to the currect node, mark the
+      /* If the key is smaller or equal to the current node, mark the
 	 entry.  In case of a non-leaf mode it will be used to lookup
 	 the rest of the tree.  */
       if (cmp <= 0)

Modified: trunk/grub2/fs/reiserfs.c
===================================================================
--- trunk/grub2/fs/reiserfs.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/fs/reiserfs.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -809,7 +809,7 @@
                   grub_uint32_t entry_block_number;
                   /* Order is very important here.
                      First set the offset to 0 using current key version.
-                     Then change the key type, which influes on key version
+                     Then change the key type, which affects key version
                      detection.  */
                   grub_reiserfs_set_key_offset (&entry_key, 0);
                   grub_reiserfs_set_key_type (&entry_key, GRUB_REISERFS_STAT,

Modified: trunk/grub2/fs/udf.c
===================================================================
--- trunk/grub2/fs/udf.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/fs/udf.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -570,7 +570,7 @@
     }
 
   data->npd = data->npm = 0;
-  /* Locate Partiton Descriptor (PD) and Logical Volume Descriptor (LVD).  */
+  /* Locate Partition Descriptor (PD) and Logical Volume Descriptor (LVD).  */
   while (1)
     {
       struct grub_udf_tag tag;

Modified: trunk/grub2/include/grub/command.h
===================================================================
--- trunk/grub2/include/grub/command.h	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/include/grub/command.h	2009-05-04 20:06:05 UTC (rev 2184)
@@ -67,7 +67,7 @@
   /* The description of the command.  */
   const char *description;
 
-  /* Arbitary data.  */
+  /* Arbitrary data.  */
   void *data;
 };
 typedef struct grub_command *grub_command_t;

Modified: trunk/grub2/include/grub/efiemu/efiemu.h
===================================================================
--- trunk/grub2/include/grub/efiemu/efiemu.h	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/include/grub/efiemu/efiemu.h	2009-05-04 20:06:05 UTC (rev 2184)
@@ -99,7 +99,7 @@
 extern grub_efi_system_table32_t *grub_efiemu_system_table32;
 extern grub_efi_system_table64_t *grub_efiemu_system_table64;
 
-/* Convenience macroses to access currently loaded efiemu */
+/* Convenience macros to access currently loaded efiemu */
 #define grub_efiemu_system_table ((grub_efiemu_sizeof_uintn_t () == 8) \
 				  ? (void *) grub_efiemu_system_table64 \
 				  : (void *) grub_efiemu_system_table32)

Modified: trunk/grub2/include/grub/elf.h
===================================================================
--- trunk/grub2/include/grub/elf.h	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/include/grub/elf.h	2009-05-04 20:06:05 UTC (rev 2184)
@@ -206,18 +206,18 @@
 #define EM_68HC12	53		/* Motorola M68HC12 */
 #define EM_MMA		54		/* Fujitsu MMA Multimedia Accelerator*/
 #define EM_PCP		55		/* Siemens PCP */
-#define EM_NCPU		56		/* Sony nCPU embeeded RISC */
+#define EM_NCPU		56		/* Sony nCPU embedded RISC */
 #define EM_NDR1		57		/* Denso NDR1 microprocessor */
 #define EM_STARCORE	58		/* Motorola Start*Core processor */
 #define EM_ME16		59		/* Toyota ME16 processor */
-#define EM_ST100	60		/* STMicroelectronic ST100 processor */
+#define EM_ST100	60		/* STMicroelectronics ST100 processor */
 #define EM_TINYJ	61		/* Advanced Logic Corp. Tinyj emb.fam*/
 #define EM_X86_64	62		/* AMD x86-64 architecture */
 #define EM_PDSP		63		/* Sony DSP Processor */
 
 #define EM_FX66		66		/* Siemens FX66 microcontroller */
 #define EM_ST9PLUS	67		/* STMicroelectronics ST9+ 8/16 mc */
-#define EM_ST7		68		/* STmicroelectronics ST7 8 bit mc */
+#define EM_ST7		68		/* STMicroelectronics ST7 8 bit mc */
 #define EM_68HC16	69		/* Motorola MC68HC16 microcontroller */
 #define EM_68HC11	70		/* Motorola MC68HC11 microcontroller */
 #define EM_68HC08	71		/* Motorola MC68HC08 microcontroller */
@@ -319,7 +319,7 @@
 #define SHT_FINI_ARRAY	  15		/* Array of destructors */
 #define SHT_PREINIT_ARRAY 16		/* Array of pre-constructors */
 #define SHT_GROUP	  17		/* Section group */
-#define SHT_SYMTAB_SHNDX  18		/* Extended section indeces */
+#define SHT_SYMTAB_SHNDX  18		/* Extended section indices */
 #define	SHT_NUM		  19		/* Number of defined types.  */
 #define SHT_LOOS	  0x60000000	/* Start OS-specific */
 #define SHT_GNU_LIBLIST	  0x6ffffff7	/* Prelink library list */
@@ -1191,7 +1191,7 @@
 #define R_SPARC_LM22		36	/* Low middle 22 bits of ... */
 #define R_SPARC_PC_HH22		37	/* Top 22 bits of pc rel 64 bit */
 #define R_SPARC_PC_HM10		38	/* High middle 10 bit of ... */
-#define R_SPARC_PC_LM22		39	/* Low miggle 22 bits of ... */
+#define R_SPARC_PC_LM22		39	/* Low middle 22 bits of ... */
 #define R_SPARC_WDISP16		40	/* PC relative 16 bit shifted */
 #define R_SPARC_WDISP19		41	/* PC relative 19 bit shifted */
 #define R_SPARC_7		43	/* Direct 7 bit */
@@ -1625,9 +1625,9 @@
 #define EFA_PARISC_1_1		    0x0210 /* PA-RISC 1.1 big-endian.  */
 #define EFA_PARISC_2_0		    0x0214 /* PA-RISC 2.0 big-endian.  */
 
-/* Additional section indeces.  */
+/* Additional section indices.  */
 
-#define SHN_PARISC_ANSI_COMMON	0xff00	   /* Section for tenatively declared
+#define SHN_PARISC_ANSI_COMMON	0xff00	   /* Section for tentatively declared
 					      symbols in ANSI C.  */
 #define SHN_PARISC_HUGE_COMMON	0xff01	   /* Common blocks in huge model.  */
 
@@ -1784,7 +1784,7 @@
 
 /* Legal values for sh_type field of Elf64_Shdr.  */
 
-/* These two are primerily concerned with ECOFF debugging info.  */
+/* These two are primarily concerned with ECOFF debugging info.  */
 #define SHT_ALPHA_DEBUG		0x70000001
 #define SHT_ALPHA_REGINFO	0x70000002
 

Modified: trunk/grub2/include/grub/lib/LzmaEnc.h
===================================================================
--- trunk/grub2/include/grub/lib/LzmaEnc.h	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/include/grub/lib/LzmaEnc.h	2009-05-04 20:06:05 UTC (rev 2184)
@@ -60,7 +60,7 @@
 Returns:
   SZ_OK           - OK
   SZ_ERROR_MEM    - Memory allocation error
-  SZ_ERROR_PARAM  - Incorrect paramater in props
+  SZ_ERROR_PARAM  - Incorrect parameter in props
   SZ_ERROR_WRITE  - Write callback error.
   SZ_ERROR_PROGRESS - some break from progress callback
   SZ_ERROR_THREAD - errors in multithreading functions (only for Mt version)
@@ -83,7 +83,7 @@
 Return code:
   SZ_OK               - OK
   SZ_ERROR_MEM        - Memory allocation error
-  SZ_ERROR_PARAM      - Incorrect paramater
+  SZ_ERROR_PARAM      - Incorrect parameter
   SZ_ERROR_OUTPUT_EOF - output buffer overflow
   SZ_ERROR_THREAD     - errors in multithreading functions (only for Mt version)
 */

Modified: trunk/grub2/include/grub/script_sh.h
===================================================================
--- trunk/grub2/include/grub/script_sh.h	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/include/grub/script_sh.h	2009-05-04 20:06:05 UTC (rev 2184)
@@ -170,7 +170,7 @@
      function.  */
   struct grub_script_mem *func_mem;
 
-  /* When set to 0, no errors have occured during parsing.  */
+  /* When set to 0, no errors have occurred during parsing.  */
   int err;
 
   /* The memory that was used while parsing and scanning.  */

Modified: trunk/grub2/include/grub/usb.h
===================================================================
--- trunk/grub2/include/grub/usb.h	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/include/grub/usb.h	2009-05-04 20:06:05 UTC (rev 2184)
@@ -155,7 +155,7 @@
   /* Device speed.  */
   grub_usb_speed_t speed;
 
-  /* All desciptors are read if this is set to 1.  */
+  /* All descriptors are read if this is set to 1.  */
   int initialized;
 
   /* Data toggle values (used for bulk transfers only).  */

Modified: trunk/grub2/include/grub/usbdesc.h
===================================================================
--- trunk/grub2/include/grub/usbdesc.h	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/include/grub/usbdesc.h	2009-05-04 20:06:05 UTC (rev 2184)
@@ -62,7 +62,7 @@
 } __attribute__ ((packed));
 
 #if 0
-struct grub_usb_desc_ifassosiation
+struct grub_usb_desc_if_association
 {
   grub_uint8_t length;
   grub_uint8_t type;

Modified: trunk/grub2/include/grub/xnu.h
===================================================================
--- trunk/grub2/include/grub/xnu.h	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/include/grub/xnu.h	2009-05-04 20:06:05 UTC (rev 2184)
@@ -27,7 +27,7 @@
   /* Size of the image. Notice that file containing image is usually bigger. */
   grub_uint64_t image_size;
   grub_uint8_t unknown1[8];
-  /* Where to copy lauchcode?*/
+  /* Where to copy launchcode? */
   grub_uint32_t launchcode_target_page;
   /* How many pages of launchcode? */
   grub_uint32_t launchcode_numpages;

Modified: trunk/grub2/kern/ieee1275/cmain.c
===================================================================
--- trunk/grub2/kern/ieee1275/cmain.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/kern/ieee1275/cmain.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -130,7 +130,7 @@
 
 	 - SD cards.  These work fine.
 
-	 To avoid brekage, we only need to skip USB probing.  However,
+	 To avoid breakage, we only need to skip USB probing.  However,
 	 since detecting SD cards is more reliable, we do that instead.
       */
 

Modified: trunk/grub2/kern/ieee1275/init.c
===================================================================
--- trunk/grub2/kern/ieee1275/init.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/kern/ieee1275/init.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -150,7 +150,7 @@
 
     /* In theory, firmware should already prevent this from happening by not
        listing our own image in /memory/available.  The check below is intended
-       as a safegard in case that doesn't happen.  It does, however, not protect
+       as a safeguard in case that doesn't happen.  However, it doesn't protect
        us from corrupting our module area, which extends up to a
        yet-undetermined region above _end.  */
     if ((addr < (grub_addr_t) _end) && ((addr + len) > (grub_addr_t) _start))

Modified: trunk/grub2/kern/ieee1275/openfw.c
===================================================================
--- trunk/grub2/kern/ieee1275/openfw.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/kern/ieee1275/openfw.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -409,7 +409,7 @@
 void
 grub_halt (void)
 {
-  /* Not standarized.  We try both known commands.  */
+  /* Not standardized.  We try both known commands.  */
 
   grub_ieee1275_interpret ("shut-down", 0);
   grub_ieee1275_interpret ("power-off", 0);

Modified: trunk/grub2/loader/i386/bsd.c
===================================================================
--- trunk/grub2/loader/i386/bsd.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/loader/i386/bsd.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -394,7 +394,7 @@
     }
 }
 
-/* This function would be here but it's under different licence. */
+/* This function would be here but it's under different license. */
 #include "bsd_pagetable.c"
 
 struct gdt_descriptor

Modified: trunk/grub2/loader/i386/bsd_trampoline.S
===================================================================
--- trunk/grub2/loader/i386/bsd_trampoline.S	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/loader/i386/bsd_trampoline.S	2009-05-04 20:06:05 UTC (rev 2184)
@@ -98,7 +98,7 @@
 	orl	$CR0_PG, %eax
 	movl	%eax, %cr0
 
-	/* Now we're in compatability mode. set %cs for long mode.  */
+	/* Now we're in compatibility mode. set %cs for long mode.  */
 	/* lgdt */
 	.byte 0x0f
 	.byte 0x01

Modified: trunk/grub2/loader/macho.c
===================================================================
--- trunk/grub2/loader/macho.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/loader/macho.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -121,7 +121,7 @@
   grub_ssize_t read;
   if (! grub_macho_contains_macho32 (macho))
     return grub_error (GRUB_ERR_BAD_OS, 
-		       "Couldn't read arcitecture-specific part");
+		       "Couldn't read architecture-specific part");
 
   if (grub_file_seek (macho->file, macho->offset32) == (grub_off_t) -1)
     {
@@ -136,7 +136,7 @@
     {
       grub_error_push ();
       return grub_error (GRUB_ERR_BAD_OS, 
-			 "Couldn't read arcitecture-specific part");
+			 "Couldn't read architecture-specific part");
     }
   return GRUB_ERR_NONE;
 }

Modified: trunk/grub2/loader/sparc64/ieee1275/linux.c
===================================================================
--- trunk/grub2/loader/sparc64/ieee1275/linux.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/loader/sparc64/ieee1275/linux.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -97,7 +97,7 @@
 
   hp = (struct linux_hdrs *) linux_addr;
 
-  /* Any pointer we derefence in the kernel image must be relocated
+  /* Any pointer we dereference in the kernel image must be relocated
      to where we actually loaded the kernel.  */
   addr = (grub_addr_t) hp->bootstr_info;
   addr += (linux_addr - linux_entry);
@@ -474,7 +474,7 @@
 
   if (grub_ieee1275_get_property (node, "translations", of_trans, actual, &actual))
     {
-      grub_printf ("Cannot fetch /vritual-memory/translations property.\n");
+      grub_printf ("Cannot fetch /virtual-memory/translations property.\n");
       return;
     }
 

Modified: trunk/grub2/loader/xnu.c
===================================================================
--- trunk/grub2/loader/xnu.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/loader/xnu.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -1053,7 +1053,7 @@
   return GRUB_ERR_NONE;
 }
 
-/* Load extension DIRNAME. (extensions are directoris in xnu) */
+/* Load extension DIRNAME. (extensions are directories in xnu) */
 grub_err_t
 grub_xnu_load_kext_from_dir (char *dirname, char *osbundlerequired, 
 			     int maxrecursion)
@@ -1226,7 +1226,7 @@
   grub_file_t binfile = 0;
   if (argc == 2)
     {
-      /* User explicitely specified plist and binary. */
+      /* User explicitly specified plist and binary. */
       if (grub_strcmp (args[1], "-") != 0)
 	{
 	  binfile = grub_gzfile_open (args[1], 1);

Modified: trunk/grub2/mmap/i386/uppermem.c
===================================================================
--- trunk/grub2/mmap/i386/uppermem.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/mmap/i386/uppermem.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -63,7 +63,7 @@
   return upper;
 }
 
-/* Count the continous bytes after 64 MiB. */
+/* Count the continuous bytes after 64 MiB. */
 grub_uint64_t 
 grub_mmap_get_post64 (void)
 {

Modified: trunk/grub2/mmap/mmap.c
===================================================================
--- trunk/grub2/mmap/mmap.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/mmap/mmap.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -212,7 +212,7 @@
 	if (present[k] && (curtype == -1 || priority[k] > priority[curtype]))
 	  curtype = k;
 
-      /* Anounce region to the hook if necessary. */
+      /* Announce region to the hook if necessary. */
       if ((curtype == -1 || curtype != lasttype) 
 	  && lastaddr != scanline_events[i].pos
 	  && lasttype != -1

Modified: trunk/grub2/normal/datetime.c
===================================================================
--- trunk/grub2/normal/main.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/normal/main.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -390,8 +390,8 @@
 
 static int reader_nested;
 
-/* Read the config file COFIG, and execute the menu interface or
-   the command-line interface if BATCH is false.  */
+/* Read the config file CONFIG and execute the menu interface or
+   the command line interface if BATCH is false.  */
 void
 grub_normal_execute (const char *config, int nested, int batch)
 {

Modified: trunk/grub2/normal/menu.c
===================================================================
--- trunk/grub2/normal/menu.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/normal/menu.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -83,7 +83,7 @@
 }
 
 /* Get the first entry number from the value of the environment variable NAME,
-   which is a space-separated list of nonnegative integers.  The entry number
+   which is a space-separated list of non-negative integers.  The entry number
    which is returned is stripped from the value of NAME.  If no entry number
    can be found, -1 is returned.  */
 static int

Modified: trunk/grub2/partmap/apple.c
===================================================================
--- trunk/grub2/partmap/apple.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/partmap/apple.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -77,7 +77,7 @@
   /* Reserved.  */
   grub_uint32_t reserved2;
   
-  /* The entrypoint of the bootcode.  */
+  /* The entry point of the bootcode.  */
   grub_uint32_t bootcode_entrypoint;
 
   /* Reserved.  */

Modified: trunk/grub2/term/i386/pc/vesafb.c
===================================================================
--- trunk/grub2/term/i386/pc/vesafb.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/term/i386/pc/vesafb.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -83,7 +83,7 @@
   struct grub_colored_char *text_buffer;
 };
 
-/* Make seure text buffer is not marked as allocated.  */
+/* Make sure text buffer is not marked as allocated.  */
 static struct grub_virtual_screen virtual_screen =
   {
     .text_buffer = 0

Modified: trunk/grub2/term/usb_keyboard.c
===================================================================
--- trunk/grub2/term/usb_keyboard.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/term/usb_keyboard.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -92,7 +92,7 @@
   /* Place the device in boot mode.  */
   grub_usb_control_msg (usbdev, 0x21, 0x0B, 0, 0, 0, 0);
 
-  /* Reports everytime an event occurs and not more often than that.  */
+  /* Reports every time an event occurs and not more often than that.  */
   grub_usb_control_msg (usbdev, 0x21, 0x0A, 0<<8, 0, 0, 0);
 }
 

Modified: trunk/grub2/util/getroot.c
===================================================================
--- trunk/grub2/util/getroot.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/util/getroot.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -351,7 +351,7 @@
   /* Cygwin returns the partition serial number in stat.st_dev.
      This is never identical to the device number of the emulated
      /dev/sdXN device, so above find_root_device () does not work.
-     Search the partion with the same serial in boot sector instead.  */
+     Search the partition with the same serial in boot sector instead.  */
   char devpath[sizeof ("/dev/sda15") + 13]; /* Size + Paranoia.  */
   int d;
   for (d = 'a'; d <= 'z'; d++)

Modified: trunk/grub2/util/resolve.c
===================================================================
--- trunk/grub2/util/resolve.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/util/resolve.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -101,7 +101,7 @@
 	  struct mod_list *mod;
 	  char *name;
 
-	  /* Skip white spaces.  */
+	  /* Skip whitespace.  */
 	  while (*p && isspace (*p))
 	    p++;
 
@@ -110,7 +110,7 @@
 
 	  name = p;
 
-	  /* Skip non-WSPs.  */
+	  /* Skip non-whitespace.  */
 	  while (*p && ! isspace (*p))
 	    p++;
 

Modified: trunk/grub2/video/i386/pc/vbe.c
===================================================================
--- trunk/grub2/video/i386/pc/vbe.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/video/i386/pc/vbe.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -42,7 +42,7 @@
     {0x00, 0x00, 0xA8, 0x00}, // 4 = red
     {0xA8, 0x00, 0xA8, 0x00}, // 5 = magenta
     {0x00, 0x54, 0xA8, 0x00}, // 6 = brown
-    {0xA8, 0xA8, 0xA8, 0x00}, // 7 = ligth gray
+    {0xA8, 0xA8, 0xA8, 0x00}, // 7 = light gray
 
     {0x54, 0x54, 0x54, 0x00}, // 8 = dark gray
     {0xFE, 0x54, 0x54, 0x00}, // 9 = bright blue
@@ -1552,7 +1552,7 @@
   if (! target)
     return GRUB_ERR_NONE;
 
-  /* TODO: Delist render target fron render target list.  */
+  /* TODO: Delist render target from render target list.  */
 
   /* If this is software render target, free it's memory.  */
   if (target->is_allocated)

Modified: trunk/grub2/video/readers/png.c
===================================================================
--- trunk/grub2/video/readers/png.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/video/readers/png.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -109,7 +109,7 @@
 
   grub_uint8_t *cur_rgb;
 
-  int cur_colume, cur_filter, first_line;
+  int cur_column, cur_filter, first_line;
 };
 
 static grub_uint32_t
@@ -265,7 +265,7 @@
 
   data->raw_bytes = data->image_height * (data->image_width + 1) * data->bpp;
 
-  data->cur_colume = 0;
+  data->cur_column = 0;
   data->first_line = 1;
 
   if (grub_png_get_byte (data) != PNG_COMPRESSION_BASE)
@@ -522,7 +522,7 @@
   if (--data->raw_bytes < 0)
     return grub_error (GRUB_ERR_BAD_FILE_TYPE, "image size overflown");
 
-  if (data->cur_colume == 0)
+  if (data->cur_column == 0)
     {
       if (n >= PNG_FILTER_VALUE_LAST)
 	return grub_error (GRUB_ERR_BAD_FILE_TYPE, "invalid filter value");
@@ -532,9 +532,9 @@
   else
     *(data->cur_rgb++) = n;
 
-  data->cur_colume++;
+  data->cur_column++;
   row_bytes = data->image_width * data->bpp;
-  if (data->cur_colume == row_bytes + 1)
+  if (data->cur_column == row_bytes + 1)
     {
       grub_uint8_t *blank_line = NULL;
       grub_uint8_t *cur = data->cur_rgb - row_bytes;
@@ -623,7 +623,7 @@
       if (blank_line)
 	grub_free (blank_line);
 
-      data->cur_colume = 0;
+      data->cur_column = 0;
       data->first_line = 0;
     }
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.
--- trunk/grub2/bus/usb/uhci.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/bus/usb/uhci.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -56,7 +56,7 @@
   grub_uint8_t pad[8];
 } __attribute__ ((packed));
 
-/* UHCI Tranfer Descriptor.  */
+/* UHCI Transfer Descriptor.  */
 struct grub_uhci_td
 {
   /* Pointer to the next TD in the list.  */
@@ -248,7 +248,7 @@
   grub_uhci_writereg32 (u, GRUB_UHCI_REG_FLBASEADD,
 			(grub_uint32_t) u->framelist);
 
-  /* Make the Queue Heads point to eachother.  */
+  /* Make the Queue Heads point to each other.  */
   for (i = 0; i < 256; i++)
     {
       /* Point to the next QH.  */
@@ -482,7 +482,7 @@
   grub_dprintf ("uhci", "initiate transaction\n");
 
   /* Wait until either the transaction completed or an error
-     occured.  */
+     occurred.  */
   for (;;)
     {
       grub_uhci_td_t errtd;
@@ -507,30 +507,30 @@
 	  if (errtd->ctrl_status & (1 << 22))
 	    err = GRUB_USB_ERR_STALL;
 
 	  /* Check if an error related to the data buffer occured.  */
 	  if (errtd->ctrl_status & (1 << 21))
 	    err = GRUB_USB_ERR_DATA;
 
 	  /* Check if a babble error occured.  */
 	  if (errtd->ctrl_status & (1 << 20))
 	    err = GRUB_USB_ERR_BABBLE;
  
 	  /* Check if a NAK occured.  */
 	  if (errtd->ctrl_status & (1 << 19))
 	    err = GRUB_USB_ERR_NAK;
 
 	  /* Check if a timeout occured.  */
 	  if (errtd->ctrl_status & (1 << 18))
 	    err = GRUB_USB_ERR_TIMEOUT;
 
 	  /* Check if a bitstuff error occured.  */
 	  if (errtd->ctrl_status & (1 << 17))
 	    err = GRUB_USB_ERR_BITSTUFF;
 
 	  if (err)
 	    goto fail;
 
 	  /* Fall through, no errors occured, so the QH might be
 	     updated.  */
 	  grub_dprintf ("uhci", "transaction fallthrough\n");
 	}
@@ -660,7 +660,7 @@
 {
   grub_uhci_inithw ();
   grub_usb_controller_dev_register (&usb_controller);
-  grub_dprintf ("uhci", "registed\n");
+  grub_dprintf ("uhci", "registered\n");
 }
 
 GRUB_MOD_FINI(uhci)
@@ -507,30 +507,30 @@
 	    err = GRUB_USB_ERR_STALL;
 
-	  /* Check if an error related to the data buffer occured.  */
+	  /* Check if an error related to the data buffer occurred.  */
 	  if (errtd->ctrl_status & (1 << 21))
 	    err = GRUB_USB_ERR_DATA;
@@ -507,30 +507,30 @@
 	    err = GRUB_USB_ERR_DATA;
 
-	  /* Check if a babble error occured.  */
+	  /* Check if a babble error occurred.  */
 	  if (errtd->ctrl_status & (1 << 20))
 	    err = GRUB_USB_ERR_BABBLE;
@@ -507,30 +507,30 @@
 	    err = GRUB_USB_ERR_BABBLE;
  
-	  /* Check if a NAK occured.  */
+	  /* Check if a NAK occurred.  */
 	  if (errtd->ctrl_status & (1 << 19))
 	    err = GRUB_USB_ERR_NAK;
@@ -507,30 +507,30 @@
 	    err = GRUB_USB_ERR_NAK;
 
-	  /* Check if a timeout occured.  */
+	  /* Check if a timeout occurred.  */
 	  if (errtd->ctrl_status & (1 << 18))
 	    err = GRUB_USB_ERR_TIMEOUT;
@@ -507,30 +507,30 @@
 	    err = GRUB_USB_ERR_TIMEOUT;
 
-	  /* Check if a bitstuff error occured.  */
+	  /* Check if a bitstuff error occurred.  */
 	  if (errtd->ctrl_status & (1 << 17))
 	    err = GRUB_USB_ERR_BITSTUFF;
@@ -507,30 +507,30 @@
 	    goto fail;
 
-	  /* Fall through, no errors occured, so the QH might be
+	  /* Fall through, no errors occurred, so the QH might be
 	     updated.  */
 	  grub_dprintf ("uhci", "transaction fallthrough\n");

Modified: trunk/grub2/commands/acpi.c
===================================================================
--- trunk/grub2/normal/datetime.c	2009-05-04 19:38:12 UTC (rev 2183)
+++ trunk/grub2/normal/datetime.c	2009-05-04 20:06:05 UTC (rev 2184)
@@ -64,7 +64,7 @@
   /* In the period of validity of unixtime all years divisible by 4 
      are bissextile*/
   /* Convenience: let's have 3 consecutive non-bissextile years 
-     at the begining of the epoch. So count from 1973 instead of 1970 */
+     at the beginning of the epoch. So count from 1973 instead of 1970 */
   nix -= 3*SECPERYEAR + SECPERDAY;
   /* Transform C divisions and modulos to mathematical ones */
   div = nix / SECPER4YEARS;
@@ -73,8 +73,8 @@
   datetime->year = 1973 + 4 * div;
   nix -= div * SECPER4YEARS;
 
-  /* On 31st december of bissextile years 365 days from the begining 
-     of the year elapsed but year isn't finished yet*/
+  /* On 31st December of bissextile years 365 days from the beginning
+     of the year elapsed but year isn't finished yet */
   if (nix / SECPERYEAR == 4)
     {
       datetime->year += 3;

Modified: trunk/grub2/normal/main.c
===================================================================